@@ -6,6 +6,7 @@ import platform
 import sys
 import pkgutil
 import re
+import pylfl 
 
 # determine platform at runtime
 system = platform.system()
@@ -16,6 +17,8 @@ if system == 'Windows':
     opsys='win'
 if system == 'Darwin':
     opsys='mac'
+# determine relative path at runtime
+path = pylfl.__path__[0]
 
 # Adds a line to some *data file.
 def add_keyword(keyword, filename:str, params=None):
@@ -47,9 +50,9 @@ def gmin():
         f = open("gmin_output.txt", "w")
         # execute GMIN binary as defined by setup.py for correct OS
         if opsys != 'win':
-            subprocess.call(f'bin/{opsys}/GMIN', stdout=f)
+            subprocess.call(path+f'/bin/{opsys}/GMIN', stdout=f)
         else:
-            subprocess.call('bin/win/GMIN.exe', stdout=f)
+            subprocess.call(path+'/bin/win/GMIN.exe', stdout=f)
     else:
         print('Data or coords file are missing')		
 
@@ -60,9 +63,9 @@ def optim(outfile='optim_output.txt'):
         f = open(outfile, "w")
         # execute OPTIM binary as defined by setup.py for correct OS
         if opsys != 'win':
-            subprocess.call(f'bin/{opsys}/OPTIM', stdout=f)
+            subprocess.call(path+f'/bin/{opsys}/OPTIM', stdout=f)
         else:
-            subprocess.call('bin/win/OPTIM.exe', stdout=f)
+            subprocess.call(path+'/bin/win/OPTIM.exe', stdout=f)
     else:
         print('odata file is missing')
 
@@ -73,9 +76,9 @@ def pathsample():
         f = open("pathsample_output.txt", "w")
         # execute PS binary as defined by setup.py for correct OS
         if opsys != 'win':
-            subprocess.call(f'bin/{opsys}/PATHSAMPLE', stdout=f)
+            subprocess.call(path+f'/bin/{opsys}/PATHSAMPLE', stdout=f)
         else:
-            subprocess.call('bin/win/PATHSAMPLE.exe', stdout=f)
+            subprocess.call(path+'/bin/win/PATHSAMPLE.exe', stdout=f)
     else:
         print('pathdata file is missing')
 
